summaryrefslogtreecommitdiffstats
path: root/src/lib/dns/question.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib/dns/question.h')
-rw-r--r--src/lib/dns/question.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/lib/dns/question.h b/src/lib/dns/question.h
index efd6c3f167..088ca9fdfc 100644
--- a/src/lib/dns/question.h
+++ b/src/lib/dns/question.h
@@ -106,8 +106,8 @@ public:
/// It may throw an exception if the construction of these component
/// classes fails.
///
- /// \param buffer A buffer storing the wire format data.
- Question(isc::util::InputBuffer& buffer);
+ /// \param buff A buffer storing the wire format data.
+ Question(isc::util::InputBuffer& buff);
/// \brief Constructor from fixed parameters of the \c Question.
///